translate

Package translate |
[hide private]
[frames] | no frames]

# Source Code for Package translate

     1  #!/usr/bin/env python
     2  # -*- coding: utf-8 -*-
     3  #
     4  # Copyright 2008-2010 Zuza Software Foundation
     5  #
     6  # This file is part of the Translate Toolkit.
     7  #
     8  # This program is free software; you can redistribute it and/or modify
     9  # it under the terms of the GNU General Public License as published by
    10  # the Free Software Foundation; either version 2 of the License, or
    11  # (at your option) any later version.
    12  #
    13  # This program is distributed in the hope that it will be useful,
    14  # but WITHOUT ANY WARRANTY; without even the implied warranty of
    15  # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    16  # GNU General Public License for more details.
    17  #
    18  # You should have received a copy of the GNU General Public License
    19  # along with this program; if not, see <http://www.gnu.org/licenses/>.
    20
    21  """The Translate Toolkit is a Python package that assists in localization of software.
    22
    23  See U{http://translate.sourceforge.net/wiki/toolkit/index} or U{http://translate.org.za} for more information.
    24
    25  @organization: Zuza Software Foundation
    26  @copyright: 2002-2010 Zuza Software Foundation
    27  @license: U{GPL <http://www.fsf.org/licensing/licenses/gpl.html>}
    28
    29  @group Localization and Localizable File Formats: storage
    30  @group Format Converters: convert
    31  @group Localisation File Checker: filters
    32  @group Localization File Manipulation Tools: tools
    33  @group Language Specifications: lang
    34  @group Search and String Matching: search
    35  @group Services: services
    36  @group Miscellaneous: misc source_tree_infrastructure __version__ i18n
    37
    38  """
    39